@@ -1,8 +1,5 @@
-from __future__ import absolute_import
-from .fast_to_sql import fast_to_sql
-
 __project__ = "fast-to-sql"
-__version__ = "2.1.9"
+__version__ = "2.1.14"
 __keywords__ = ["pandas", "to_sql", "fast", "sql"]
 __author__ = "Jarred Glaser"
 __author_email__ = "jarred.glaser@gmail.com"
